@@ -1,69 +1,60 @@
 # coding=utf-8
 import os
 import re
+import io
 import tempfile
-import platform
+from PIL import Image
 
 
 class AdbExt(object):
     def __init__(self, util):
-        self.__util = util
+        self.util = util
         self.width, self.height = self.get_device_size()
-        self.temp_name = 'temp_{}'.format(self.__util.sn)  # 临时文件名加上sn，防止多个手机多线程是有冲突
+        self.temp_name = 'temp_{}'.format(self.util.sn)  # 临时文件名加上sn，防止多个手机多线程是有冲突
         self.temp_name = self.temp_name.replace('.', '').replace(':', '')  # 远程机器sn特殊，处理一下。如：10.15.34.56:11361
         self.temp_pc_dir_path = tempfile.gettempdir()
         self.temp_device_dir_path = '/data/local/tmp'
-        self.is_wsl = 'Linux' in platform.system() and 'Microsoft' in platform.release()  # 判断当前是不是WSL环境
 
     def get_device_size(self):
-        out = self.__util.shell('wm size')  # out like 'Physical size: 1080x1920'
+        out = self.util.shell('wm size')  # out like 'Physical size: 1080x1920'
         out = re.findall(r'\d+', out)
         return int(out[0]), int(out[1])  # width, height
 
-    def get_pc_temp_name(self):
-        return os.path.join(self.temp_pc_dir_path, self.temp_name)
-
-    def dump(self, pc_name=None, pc_dir_path=None, device_path=None):
-        pc_name = pc_name if pc_name else '{}.xml'.format(self.temp_name)
-        pc_path, device_path = self.__get_pc_device_path(pc_name, pc_dir_path, device_path)  # 获取绝对路径
+    def dump(self, pc_path=None, device_path=None):
+        if not pc_path:
+            pc_path = '{}.xml'.format(self.get_pc_temp_name())
+        if not device_path:
+            device_path = '{}/{}.xml'.format(self.temp_device_dir_path, self.temp_name)
         self.delete_from_pc(pc_path)  # 删除电脑文件
         self.delete_from_device(device_path)  # 删除手机文件
         try_count = 5
         while try_count:  # 如果dump失败，多次尝试
-            out = self.__util.shell('uiautomator dump {}'.format(device_path))
+            out = self.util.shell('uiautomator dump {}'.format(device_path))
             if 'UI hierchary dumped to' in out:  # 如果dump成功，退出循环
                 break
-            elif not self.is_wsl:  # 如果dump失败,重启 adb
-                self.__util.adb('kill-server')
-                self.__util.adb('start-server')
+            elif not self.util.is_wsl:  # 如果dump失败,重启 adb
+                self.util.adb('kill-server')
+                self.util.adb('start-server')
             try_count -= 1
         if try_count == 0:
             raise NameError('dump xml fail!')
-        self.pull(pc_name, pc_dir_path, device_path)
+        self.pull(device_path, pc_path)
+
+    def get_pc_temp_name(self):
+        return os.path.join(self.temp_pc_dir_path, self.temp_name)
 
     def delete_from_device(self, path):
-        self.__util.shell('rm -rf {}'.format(path))
+        self.util.shell('rm -rf {}'.format(path))
 
     def delete_from_pc(self, path):
         if os.path.exists(path): os.remove(path)
 
-    def __get_pc_device_path(self, pc_name, pc_dir_path=None, device_path=None):
-        pc_dir_path = pc_dir_path if pc_dir_path else self.temp_pc_dir_path
-        pc_path = '"{}/{}"'.format(pc_dir_path, pc_name)
-        device_path = device_path if device_path else '"{}/{}"'.format(self.temp_device_dir_path, pc_name)
-        return pc_path, device_path
-
-    def screenshot(self, pc_name=None, pc_dir_path=None, use_pull=True):
-        pc_name = pc_name if pc_name else '{}.png'.format(self.temp_name)
-        pc_path, device_path = self.__get_pc_device_path(pc_name, pc_dir_path, None)
-        self.delete_from_pc(pc_path)  # 删除电脑文件
+    def screenshot(self, pc_path=None):
+        if pc_path:
+            self.delete_from_pc(pc_path)  # 删除电脑文件
+        device_path = '{}/{}.png'.format(self.temp_device_dir_path, self.temp_name)
         self.delete_from_device(device_path)
-        if use_pull:
-            self.__util.shell('screencap -p {}'.format(device_path))
-            self.__util.adb('pull {} {}'.format(device_path, pc_path))
-            return
-        arg = 'adb -s {} exec-out screencap -p'.format(self.__util.sn)
-        self.__util.cmd_out_save(arg, pc_path, mode='wb')  # 这个命令可以直接将截图保存到电脑，节省了pull操作
+        return self.screencap()
 
     def screencap(self, pc_path=None):
         """
@@ -71,18 +62,18 @@ class AdbExt(object):
         :param pc_path:
         :return:
         """
-        arg = 'adb -s {} exec-out screencap -p'.format(self.__util.sn)
-        return self.__util.cmd_out_save(arg, pc_path, mode='wb')
+        arg = 'adb -s {} exec-out screencap -p'.format(self.util.sn)
+        png_str = self.util.cmd_out_save(arg, pc_path, mode='wb')
+        return Image.open(io.BytesIO(png_str))
 
-    def pull(self, pc_name=None, pc_dir_path=None, device_path=None):
-        pc_path, device_path = self.__get_pc_device_path(pc_name, pc_dir_path, device_path)
-        self.__util.adb('pull {} {}'.format(device_path, pc_path))
+    def pull(self, device_path=None, pc_path=None):
+        self.util.adb('pull "{}" "{}"'.format(device_path, pc_path))
 
     def push(self, pc_path=None, device_path=None):
-        self.__util.adb('push "{}" "{}"'.format(pc_path, device_path))
+        self.util.adb('push "{}" "{}"'.format(pc_path, device_path))
 
     def click(self, x, y):
-        self.__util.shell('input tap {} {}'.format(x, y))
+        self.util.shell('input tap {} {}'.format(x, y))
 
     def long_click(self, x, y, duration=''):
         """
@@ -92,7 +83,7 @@ class AdbExt(object):
         :param duration: 长按的时间（ms）
         :return:
         """
-        self.__util.shell('input touchscreen swipe {} {} {} {} {}'.format(x, y, x, y, duration))
+        self.util.shell('input touchscreen swipe {} {} {} {} {}'.format(x, y, x, y, duration))
 
     def start(self, pkg):
         """
@@ -100,25 +91,25 @@ class AdbExt(object):
         :param pkg:
         :return:
         """
-        self.__util.shell('monkey -p {} 1'.format(pkg))
+        self.util.shell('monkey -p {} 1'.format(pkg))
 
     def stop(self, pkg):
-        self.__util.shell('am force-stop {}'.format(pkg))
+        self.util.shell('am force-stop {}'.format(pkg))
 
     def input(self, text):
-        self.__util.shell('input text "{}"'.format(text.replace('&', '\&')))
+        self.util.shell('input text "{}"'.format(text.replace('&', '\&')))
 
     def back(self, times=1):
         while times:
-            self.__util.shell('input keyevent 4')
+            self.util.shell('input keyevent 4')
             times -= 1
 
     def home(self):
-        self.__util.shell('input keyevent 3')
+        self.util.shell('input keyevent 3')
 
     def enter(self, times=1):
         while times:
-            self.__util.shell('input keyevent 66')
+            self.util.shell('input keyevent 66')
             times -= 1
 
     def swipe(self, e1=None, e2=None, start_x=None, start_y=None, end_x=None, end_y=None, duration=" "):
@@ -143,7 +134,7 @@ class AdbExt(object):
         if 0 < end_y < 1:
             end_y = end_y * self.height
 
-        self.__util.shell('input swipe %s %s %s %s %s' % (str(start_x), str(start_y), str(end_x), str(end_y), str(duration)))
+        self.util.shell('input swipe %s %s %s %s %s' % (str(start_x), str(start_y), str(end_x), str(end_y), str(duration)))
 
     def clear(self, pkg):
         """
@@ -151,28 +142,28 @@ class AdbExt(object):
         :param pkg:
         :return:
         """
-        self.__util.shell('pm clear {}'.format(pkg))
+        self.util.shell('pm clear {}'.format(pkg))
 
     def wake_up(self):
         """
         点亮屏幕
         :return:
         """
-        self.__util.shell('input keyevent KEYCODE_WAKEUP')
+        self.util.shell('input keyevent KEYCODE_WAKEUP')
 
     def unlock(self):
         """
         解锁屏幕
         :return:
         """
-        self.__util.shell('input keyevent 82')
+        self.util.shell('input keyevent 82')
 
     def grant(self, pkg, permission):
         """
         给app赋权限，类似 adb shell pm grant [PACKAGE_NAME] android.permission.PACKAGE_USAGE_STATS
         :return:
         """
-        self.__util.shell('pm grant {} {}'.format(pkg, permission))
+        self.util.shell('pm grant {} {}'.format(pkg, permission))
 
     def install(self, apk_path, with_g=True, with_r=False):
         """
@@ -187,7 +178,7 @@ class AdbExt(object):
             arg = arg + ' -g'
         if with_r:
             arg = arg + ' -r'
-        self.__util.adb('{} "{}"'.format(arg, apk_path))
+        self.util.adb('{} "{}"'.format(arg, apk_path))
 
     def uninstall(self, pkg):
         """
@@ -195,4 +186,4 @@ class AdbExt(object):
         :param pkg:
         :return:
         """
-        self.__util.adb('uninstall {}'.format(pkg))
+        self.util.adb('uninstall {}'.format(pkg))
